diff th_regex.c @ 771:c17eadc60c3d

Rename th_ioctx struct to th_ioctx_t, for consistency. Breaks API.
author Matti Hamalainen <ccr@tnsp.org>
date Mon, 20 Feb 2023 23:33:45 +0200
parents 31bc1ed07cf5
children
line wrap: on
line diff
--- a/th_regex.c	Sun Feb 12 14:08:09 2023 +0200
+++ b/th_regex.c	Mon Feb 20 23:33:45 2023 +0200
@@ -9,7 +9,7 @@
 
 
 #ifdef TH_EXPERIMENTAL_REGEX_DEBUG
-th_ioctx *th_dbg_fh = NULL;
+th_ioctx_t *th_dbg_fh = NULL;
 
 #    define DBG_RE_PRINT(...) do { \
         if (th_dbg_fh != NULL) \
@@ -752,14 +752,14 @@
 }
 
 
-static void th_regex_dump_indent(th_ioctx *fh, const int level)
+static void th_regex_dump_indent(th_ioctx_t *fh, const int level)
 {
     for (int indent = 0; indent < level; indent++)
         thfputs("    ", fh);
 }
 
 
-static void th_regex_dump_node(th_ioctx *fh, const th_regex_node_t *node)
+static void th_regex_dump_node(th_ioctx_t *fh, const th_regex_node_t *node)
 {
     thfprintf(fh,
         "%s %s ",
@@ -810,14 +810,14 @@
 
 /**
  * Print out the contents of given regular expression structure @p expr
  * in "human-readable" format to specified @c th_ioctx context. Typically
  * useful for debugging purposes only.
  *
- * @param[in,out] fh th_ioctx handle to be used for output, must be writable.
+ * @param[in,out] fh th_ioctx.handle to be used for output, must be writable.
  * @param[in] level starting whitespace indentation level
  * @param[in] expr regular expression structure to be "dumped"
  */
-void th_regex_dump(th_ioctx *fh, const int level, const th_regex_t *expr)
+void th_regex_dump(th_ioctx_t *fh, const int level, const th_regex_t *expr)
 {
     if (expr != NULL)
     {
@@ -810,14 +810,14 @@
 /**
  * Print out the contents of given regular expression structure @p expr
- * in "human-readable" format to specified @c th_ioctx context. Typically
+ * in "human-readable" format to specified @c th_ioctx_t context. Typically
  * useful for debugging purposes only.
  *